==> common-1.3.0.58-sources.jar: cn/gtmap/gtc/workflow/entity/StrategyInfo.java <==
package cn.gtmap.gtc.workflow.entity;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "ACT_CF_STRATEGY_INFO")
public class StrategyInfo {


    @Column(name = "strategy_type")
    private String strategyType;

    @Column(name = "url")
    private String url;

    @Column(name = "appname")
    private String appName;

    @Column(name = "node_type")
    private String nodeType;

    @Column(name = "process_def_key")
    private String processDefKey;


    @Column(name = "activity_id")
    private String activityId;


    public String getStrategyType() {
        return strategyType;
    }

    public StrategyInfo setStrategyType(String strategyType) {
        this.strategyType = strategyType;
        return this;
    }

    public String getUrl() {
        return url;
    }

    public StrategyInfo setUrl(String url) {
        this.url = url;
        return this;
    }

    public String getAppName() {
        return appName;
    }

    public StrategyInfo setAppName(String appName) {
        this.appName = appName;
        return this;
    }

    public String getNodeType() {
        return nodeType;
    }

    public StrategyInfo setNodeType(String nodeType) {
        this.nodeType = nodeType;
        return this;
    }

    public String getProcessDefKey() {
        return processDefKey;
    }

    public StrategyInfo setProcessDefKey(String processDefKey) {
        this.processDefKey = processDefKey;
        return this;
    }

    public String getActivityId() {
        return activityId;
    }

    public StrategyInfo setActivityId(String activityId) {
        this.activityId = activityId;
        return this;
    }
}

==> common-1.3.0.66-sources.jar: cn/gtmap/gtc/workflow/entity/StrategyInfo.java <==
package cn.gtmap.gtc.workflow.entity;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "ACT_CF_STRATEGY_INFO")
public class StrategyInfo {


    @Column(name = "strategy_type")
    private String strategyType;

    @Column(name = "url")
    private String url;

    @Column(name = "appname")
    private String appName;

    @Column(name = "node_type")
    private String nodeType;

    @Column(name = "process_def_key")
    private String processDefKey;


    @Column(name = "activity_id")
    private String activityId;

    @Column(name = "DISPATCH_ENABLED")
    private String enabled;

    public String getStrategyType() {
        return strategyType;
    }

    public StrategyInfo setStrategyType(String strategyType) {
        this.strategyType = strategyType;
        return this;
    }

    public String getUrl() {
        return url;
    }

    public StrategyInfo setUrl(String url) {
        this.url = url;
        return this;
    }

    public String getAppName() {
        return appName;
    }

    public StrategyInfo setAppName(String appName) {
        this.appName = appName;
        return this;
    }

    public String getNodeType() {
        return nodeType;
    }

    public StrategyInfo setNodeType(String nodeType) {
        this.nodeType = nodeType;
        return this;
    }

    public String getProcessDefKey() {
        return processDefKey;
    }

    public StrategyInfo setProcessDefKey(String processDefKey) {
        this.processDefKey = processDefKey;
        return this;
    }

    public String getActivityId() {
        return activityId;
    }

    public StrategyInfo setActivityId(String activityId) {
        this.activityId = activityId;
        return this;
    }

    public String getEnabled() {
        return enabled;
    }

    public StrategyInfo setEnabled(String enabled) {
        this.enabled = enabled;
        return this;
    }
}
